Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

217 documents were found matching the selected criteria.
Page: [ 1] 2 3 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Jamison | L-12-1274 | Appellant’s conviction for the kidnapping and rape of a developmentally delayed minor was supported by ample evidence. Judgment affirmed. | Osowik | 7/25/2014 | 2014-Ohio-3275
State v. Gist | L-12-1355 | Jury verdicts and trial finding appellant guilty of possession of cocaine, a violation of R.C. 2925.11(A) and (C)(4)(a) and having weapons while under disability, a violation of R.C. 2923.13(A)(3) were supported by sufficient evidence and were not against the manifest weight of the evidence. | Pietrykowski | 7/25/2014 | 2014-Ohio-3274
K. Ronald Bailey & Assoc. Co. L.P.A. v. Jeremy | E-12-081 | It is not within a trial court’s discretion to refuse to award prejudgment interest in claims falling under R.C. 1342.03(A). | Pietrykowski | 7/25/2014 | 2014-Ohio-3273
State v. Gonzalez | L-13-1206, L-13-1207 | Absent a factual background in an allegedly comparable case, similar convictions for illegal use of a minor in nudity-oriented material which resulted in divergent sentences did not render appellant’s sentence unlawful. R.C. 2929.11, R.C. 2929.12, disproportionate. | Pietrykowski | 7/25/2014 | 2014-Ohio-3272
State v. Cunningham | S-13-041 | Evidence failed to demonstrate that appellant’s intoxication rendered statements to police involuntary. Suppress; Townsend. | Pietrykowski | 7/25/2014 | 2014-Ohio-3271
In re J.S. | L-14-1055 | Trial court’s judgment terminating mother’s parental rights supported by clear and convincing evidence. No meritorious grounds for appeal. Counsel’s motion to withdraw granted. | Pietrykowski | 7/16/2014 | 2014-Ohio-3130
Wenzke v. Baird | L-13-1244 | Appellant-landlord appeals housing court’s adoption of magistrate’s decision to abate rent, terminate rental agreement and order landlord to repair or replace six non-operational windows. Because the housing condition did not materially affect health and safety or render the premises unfit or uninhabitable, appellee was not entitled to the remedies set forth under R.C. 5321.07(B). Therefore, we reverse, in part, the judgment of trial court. | Jensen | 7/11/2014 | 2014-Ohio-3069
Blumensaadt v. Put-In-Bay Police Dept. | OT-13-005 | Appellant failed to articulate or establish trial court errors. Judgment affirmed. | Osowik | 7/11/2014 | 2014-Ohio-3068
Nestor v. Tone | E-14-092 | Complaint for writ of procedendo sua sponte dismissed for failure to properly caption the action. | Singer | 7/10/2014 | 2014-Ohio-3071
In re E.S. | OT-14-008, OT-14-009, OT-14-011, OT-14-012 | Trial court’s decision terminating parental rights and granting permanent custody to agency was not against manifest weight of evidence where parents entered into joint case plan, mother failed to complete her plan, and concerns remained as to whether father had abused mother after completing batterers’ intervention program. Attorney/guardian ad litem’s testimony and report were admissible despite failure to comply with all Sup.R. 48 guidelines. | Jensen | 7/10/2014 | 2014-Ohio-3067
State v. Mathis | E-13-017 | Pursuant to Crim.R. 46(H), our disposition of the appeal automatically terminated the appeal bond. | Jensen | 7/8/2014 | 2014-Ohio-3070
Shefkiu v. Worthington Industries, Inc. | F-13-014 | Injured party who files for bankruptcy lacks standing to pursue a claim against the alleged tortfeasor because the claim is the property of the bankruptcy estate. A plaintiff who does not have standing cannot avail himself of the Rules of Civil Procedure to add an additional plaintiff, in this case the bankruptcy trustee, who does have standing. | Yarbrough | 7/3/2014 | 2014-Ohio-2970
In re E.S. | L-13-1217, L-13-1218 | A juvenile court does not abuse its discretion by committing a delinquent juvenile to the Ohio Department of Youth Services for a minimum period of 90 days for a violation of supervised release and ordering that sentence to be served consecutive to a term of commitment for attempted burglary. | Yarbrough | 7/3/2014 | 2014-Ohio-2969
State v. Hayes | L-13-1204 | When imposing a consecutive sentence the trial court erred in failing to make the findings required under R.C. 2929.14(C) in the sentencing entry. | Pietrykowski | 7/3/2014 | 2014-Ohio-2968
Wofford v. Auto Owners Ins. | L-13-1254 | Trial court did not err by vacating previous order granting a default judgment in favor of appellant. Trial court did not err by granting appellee’s motion for a directed verdict at the close of appellant’s case where appellant had not made out his case by a preponderance of the evidence. | Osowik | 6/27/2014 | 2014-Ohio-2841
Wilken v. Wachovia Bank of Delaware, N.A. | H-13-020 | The law of the case doctrine prohibits a trial court from reconsidering its judgment awarding an amount of attorney fees in a class action lawsuit after that judgment has been affirmed on appeal. Statutory postjudgment interest on a settlement agreement begins to accrue on the date the parties have designated as when the monies are due to be paid. | Yarbrough | 6/27/2014 | 2014-Ohio-2840
State v. Watson | L-13-1089 | Appellant’s Alford plea was knowingly and intelligently entered. | Singer | 6/27/2014 | 2014-Ohio-2839
State v. Taysom | H-13-031, H-13-032 | Conviction following a bench trial was not against the manifest weight of the evidence. | Singer | 6/27/2014 | 2014-Ohio-2838
State v. Carter | L-14-1012 | Appellant’s motion for allied-offense determination was properly treated as a petition for postconviction relief, was untimely filed, and was barred by the doctrine of res judicata. Additionally, appellant improperly sought retroactive application of a judicial ruling. | Jensen | 6/27/2014 | 2014-Ohio-2837
State v. English | H-13-024 | Defendant’s motion to dismiss on the basis that the state failed to preserve materially exculpatory video evidence was properly denied where the evidence was not destroyed in bad faith and defendant was able to obtain the same evidence depicted in the video through other reasonable means | Jensen | 6/27/2014 | 2014-Ohio-2836
State v. Skrepenski | WD-13-036 | Claim of ineffective assistance of trial counsel must fail where appellant does not demonstrate a reasonable probability that the outcome would have been different had counsel not committed the alleged errors. Evidence showing that appellant had previously been told never to return to Walmart property is sufficient to demonstrate that he was trespassing for the purposes of a burglary conviction based on his attempted theft of property. | Yarbrough | 6/27/2014 | 2014-Ohio-2835
State v. Williams | L-13-1053, L-13-1054 | Trial court did not err in determining an aggravated murder defendant was competent to waive counsel and defend herself at trial. Court’s waiver colloquy adequately advised defendant of the charges and potential penalties, as well as her prospects for success. Trial court properly determined that counsel waiver was voluntarily, knowingly and intelligently entered. | Singer | 6/27/2014 | 2014-Ohio-2834
In re Adoption of A.M. | H-14-007 | Trial court did not violated appellant’s due process rights by granting appellee’s petition to adopt the minor child A.M. | Osowik | 6/27/2014 | 2014-Ohio-2833
In re Guardianship of Soltesz | E-13-067, E-13-072 | R.C. 149.43 provides for relief from a public office’s noncompliance with the public records law via a mandamus action. Thus, appellant’s assignments or error challenging the probate court’s denial of his motion for correction of the record are without merit where the action is not a mandamus action. | Yarbrough | 6/27/2014 | 2014-Ohio-2832
In re Er.P. | L-14-1006 | Trial court’s finding under R.C. 2151.414(B)(1)(a) that children cannot be placed with mother within a reasonable time or should not be placed with mother is not against the manifest weight of the evidence where the child suffered abuse, the mother could not explain the injuries, and the mother did not take responsibility for the safety of her child. | Yarbrough | 6/27/2014 | 2014-Ohio-2831
State v. Galloway | L-13-1155 | A motion to correct or vacate a sentence is a petition for postconviction relief irrespective of its caption. | Singer | 6/27/2014 | 2014-Ohio-2830
State v. DeLong | WD-13-007 | In a case involving a nuisance party ordinance and a charge of underage possession of alcohol, the trial court erred when it denied the defendant’s motion to suppress where no exception to the warrant requirement for entry into a residence existed. | Pietrykowski | 6/27/2014 | 2014-Ohio-2829
Basista v. Basista | WD-13-081 | Spousal support, Child support, calculation | Singer | 6/27/2014 | 2014-Ohio-2828
State ex rel. Bristow v. Chief of Police, Cedar Point Police Dept. | E-14-008 | Accepting the allegations set forth in a public records mandamus action as true, we deny respondent’s Civ.R. 12(B)(6) motion because relator’s petition alleges: (1) he requested certain public records, (2) the respondent failed to respond to his requests, (3) relator alleges he is entitled to the records, and (4) respondent is under a clear legal duty to provide the public records. | Jensen | 6/25/2014 | 2014-Ohio-2842
Windnagle v. CSI Tax Group, L.L.C. | L-13-1171 | We find a discrepancy between the amount of renovation costs prayed for by the appellee and the amount of renovation costs awarded to appellee as setoff in the judgment entry. Because we are unable to discern the trial court’s intent based upon the limited record before us, we remand the matter to the trial court for clarification. | Jensen | 6/20/2014 | 2014-Ohio-2694
State v. Williams | S-12-039 | The trial court did not err in sentencing appellant to a maximum prison term for a third-degree felony but did err in imposing the costs of prosecution without making the statutorily required notifications. | Pietrykowski | 6/20/2014 | 2014-Ohio-2693
State v. Tunison | WD-13-046 | Appellant pled guilty to attempting to engage in a pattern of corrupt activity and was sentenced to 24 months in prison. On appeal, appellant alleges multiple procedural errors under Crim.R. 11, 32, and R.C. 2947.23. We affirm appellant’s conviction. | Jensen | 6/20/2014 | 2014-Ohio-2692
State v. Mitchell | L-13-1149 | Trial court did not abuse its discretion in sentencing appellant. Judgment affirmed. | Osowik | 6/20/2014 | 2014-Ohio-2691
State v. Rivera | L-13-1177 | Defendant’s challenge to the court’s jurisdiction was actually a challenge to venue which he waived by entering a guilty plea and which was barred by res judicata due to his failure to assert in prior appeal. Trial court’s judgment entry properly advised defendant of the consequences of a violation of postrelease control conditions and court’s failure to journalize entry within thirty days did not render judgment void. | Jensen | 6/20/2014 | 2014-Ohio-2690
State v. James | L-12-1284 | This is an appeal from a judgment of the Lucas County Court of Common Pleas which found defendant-appellant guilty of murder and two counts of felonious assault. Defendant challenges his conviction on sufficiency and manifest weight of the evidence grounds. Defendant also argues that the trial court erred by imposing consecutive sentences. For the reasons set forth below, we affirm. | Jensen | 6/20/2014 | 2014-Ohio-2689
State v. Connelly | WD-13-080 | Under either R.C. 4511.36(A)(2) or (A)(3), police officer had reasonable, articulable suspicion to initiate a traffic stop where the defendant made a left-hand turn into the far right lane of a four-lane street instead of into the lane just right of the center line. | Jensen | 6/20/2014 | 2014-Ohio-2688
Hogrefe v. Mercy St. Vincent Med. Ctr. | L-13-1265 | Appellants failed to raise a genuine issue of material fact on causation in a medical malpractice action against an occupational therapist, in which they allege that the therapist negligently failed to inform the physician of the patient’s symptoms in a timely manner, where the patient testifies that she informed the physician of her symptoms and appellants’ expert testimony confirms that such information was provided to the physician with enough time for the physician to treat the patient. | Yarbrough | 6/20/2014 | 2014-Ohio-2687
Toledo v. Adlrich | L-13-1199 | Conviction was not against the manifest weight of the evidence. Judgment affirmed. | Osowik | 6/20/2014 | 2014-Ohio-2686
State v. Washington | L-13-1201 | Imposition of consecutive sentences in contravention of state’s recommendation of concurrent sentences is not error where the trial court makes the required findings under R.C. 2929.14(C)(4), those findings are supported by the record, and the trial court informed appellant that it was not bound by the state’s recommendation | Yarbrough | 6/13/2014 | 2014-Ohio-2565
State v. Baker | WD-13-074 | The trial court properly granted defendant’s motion to suppress evidence obtained during a traffic stop where the sheriff’s deputy lacked reasonable, articulable suspicion to believe that defendant committed a marked lanes violation. | Jensen | 6/13/2014 | 2014-Ohio-2564
State v. Moore | WD-13-033 | The trial court did not err when it terminated appellant’s community control without first conducting a hearing. | Pietrykowski | 6/13/2014 | 2014-Ohio-2563
Mays v. Toledo Hosp. | L-13-1260 | The trial court did not err when it denied appellant’s Civ.R. 60(B) motion for relief from judgment. | Pietrykowski | 6/13/2014 | 2014-Ohio-2562
State v. Matthews | S-13-026 | Trial court did not apply the incorrect burden of proof and court’s finding that appellant violated probation was not an abuse of discretion. Appellant was not deprived of his right to cross-examine a witness against him, his right to make a closing statement or his right to effective assistance of counsel. | Osowik | 6/13/2014 | 2014-Ohio-2561
State v. M.H. | H-13-012 | Appellant’s due process rights were not violated at sentencing hearing where appellant has not shown he was denied the right to review the presentence investigation report. | Osowik | 6/13/2014 | 2014-Ohio-2560
Kauffman v. Kauffman | S-13-014 | In a divorce action, the trial court did not err in awarding custody, ordering child support, and allocating the parties’ assets and debts. | Pietrykowski | 6/13/2014 | 2014-Ohio-2559
Gaylord v. Tipping | L-13-1219 | We find that the trial court did not abuse its discretion when it denied a tenant’s untimely Civ.R. 53(D)(2)(b) motion to set aside magistrate’s order in a forcible entry and detainer action. | Jensen | 6/13/2014 | 2014-Ohio-2558
State v. Williams | WD-12-052 | Appellant’s conviction on one count of theft by deception was supported by sufficient evidence and was not against the manifest weight of the evidence. | Pietrykowski | 6/6/2014 | 2014-Ohio-2438
State v. Jude | WD-13-055 | Imposition of consecutive sentences is clearly and convincingly contrary to law where the trial court fails to make any of the statutorily required findings under R.C. 2929.14(C)(4). | Yarbrough | 6/6/2014 | 2014-Ohio-2437
State v. Edwards | WD-13-037 | The trial court failed to articulate reasons for enhancing defendant’s sentence on resentencing following defendant’s successful appeal. An appellate court can consider the propriety of only the sentence appealed from and, therefore, cannot affirm a trial court’s sentence on the basis that defendant’s aggregate sentence for multiple offenses had remained unchanged. | Jensen | 6/6/2014 | 2014-Ohio-2436
State v. Johnson | WD-13-008, WD-13-009 | State failed to prove service of protection orders appellant was accused of violating. Convictions vacated for want of sufficient evidence. | Singer | 6/6/2014 | 2014-Ohio-2435
Mettler v. Husted | L-13-1122 | We affirm the judgment of the trial court granting summary judgment in favor of the board of elections. The plain language of R.C. 3501.11(X) clearly and unambiguously provides that should a board of elections be unable to arrive at a decision on a question and the director submits the matter in controversy to the secretary of state, the secretary of state “shall summarily decide the question” and the secretary’s decision “shall be final.” | Jensen | 6/6/2014 | 2014-Ohio-2434
State v. McCormick | L-13-1147, L-13-1148 | Felonious assault and abduction were separate offenses with separate animus and not subject to merger. Trial court did not err in imposing maximum, consecutive sentences. | Singer | 6/6/2014 | 2014-Ohio-2433
Keller v. Knight | WD-13-066 | Granting of civil stalking protection order is not against the manifest weight of the evidence where the respondent follows, harasses, and verbally abuses the petitioner. Civ.R. 53(D)(3)(a)(iii) requirement that the magistrate notify the respondent of his opportunity to object to the findings, and the consequences for failing to object, does not apply to civil protection orders under Civ.R. 65.1. | Yarbrough | 6/6/2014 | 2014-Ohio-2432
G.K.G. Builders, Inc. v. Burgess | L-13-1228 | We find that the trial court did not abuse its discretion when it denied a tenant’s motion to set aside judgment for lack of proper service in a forcible entry and detainer action despite having received notice from the United State Postal Service that the summons issued by regular mail was “NOT DELIVERABLE AS ADDRESSED – UNABLE TO FORWARD.” | Jensen | 6/6/2014 | 2014-Ohio-2431
State v. Stine | L-13-1183 | Appellant fails to show a prejudicial effect despite the trial court improperly informing him that he may be sentenced to community control, even though the offense requires a prison sentence, where appellant states that he would like to maintain his plea of no contest even presuming that he would serve an 11-year prison sentence. | Yarbrough | 5/30/2014 | 2014-Ohio-2325
State v. Grace | L-13-1126 | Trial court’s imposition of a maximum sentence for a fifth-degree felony, which is ordered to be served consecutively to a prison term out of a separate court, is not error where the court makes the appropriate findings under R.C. 2929.13(B)(1)(b) and R.C. 2929.14(C)(4), and those findings are clearly and convincingly supported by the record. | Yarbrough | 5/30/2014 | 2014-Ohio-2324
State v. Goodwin | L-12-1341 | Defendant’s aggravated robbery and robbery convictions were not against the manifest weight of the evidence despite the fact that results of DNA analysis did not implicate him and main details of the crime came from co-defendant who entered into plea agreement. Jury instructions and admonitions were proper. | Jensen | 5/30/2014 | 2014-Ohio-2323
State v. Goings | L-13-1103 | Trial court did not abuse its discretion by denying appellant’s motion to withdraw his Alford plea; trial court made the necessary findings to impose consecutive sentences. | Singer | 5/30/2014 | 2014-Ohio-2322
State v. Polus | L-13-1119, L-13-1120 | The trial court erred in sentencing appellant to serve misdemeanor and felony sentences consecutively. The trial court also erred in imposing “6-months’” incarceration instead of “180 days.” This decision is in conflict with other appellate districts and the issue is certified to the Supreme Court. App.R. 12(B) permits modification of judgment entry instead of remanding. | Jensen | 5/30/2014 | 2014-Ohio-2321
In re A.J. | L-12-1010 | Father appeals the juvenile court’s judgment awarding him Level 1 supervised visitation of his minor children. Father’s appellate counsel filed an Anders brief, requesting leave to withdraw from the case. We grant counsel’s request and affirm the decision of the trial court. Recent termination of father’s parental rights in a companion case involving the same children (In re A.J., 2014-Ohio-421, 6th Dist. Lucas No. L-13-1118) renders the instant appeal moot. | Jensen | 5/30/2014 | 2014-Ohio-2320
Star Mgt., L.L.C. v. Fayne | L-12-1342 | In a nonpayment of rent and damages action, competent evidence was found supporting the trial court’s judgment. | Pietrykowski | 5/30/2014 | 2014-Ohio-2319
Adams Quality Heating & Cooling v. Erie Cty. Health Dept. | E-13-040 | Appellant appeals the lower court’s decision not to order his reinstatement to a plumbing registry maintained by county health department despite the court’s finding that health department’s indefinite suspension of appellant from the registry was unreasonable. We agree and remand the matter to the Erie County Court of Common Pleas with the instruction that it order the department to accept appellant’s application to register as a person engaged in the plumbing business. The lower court’s decision is affirmed in all other respects. | Jensen | 5/30/2014 | 2014-Ohio-2318
In re J.R. | F-13-015 | Clear and convincing evidence requires that the proof produce in the mind of the trier of facts a firm belief or conviction as to the facts sought to be established. | Singer | 5/27/2014 | 2014-Ohio-2317
State v. Knight | L-13-1066 | Robbery and burglary charges were not allied offenses of similar import; the imposition of a six-year term of incarceration was not unlawful. | Singer | 5/23/2014 | 2014-Ohio-2222
State v. Whitacker | WD-13-061 | The trial court erred in denying appellant’s motion to suppress because the police encounter was an investigatory stop which lacked reasonable suspicion, not a consensual encounter. Informant; multiple police. | Pietrykowski | 5/23/2014 | 2014-Ohio-2220
State v. Ottinger | L-12-1337, L-12-1338, L-12-1339, L-12-1340 | Trial court did not abuse its discretion in sentencing appellant to 68 months in prison following convictions for 5 felony offenses. | Pietrykowski | 5/23/2014 | 2014-Ohio-2219
State v. Minton | OT-13-030, OT-13-031 | Notice of potential operator’s license suspension in written plea agreement substantially complied with rule that defendant be informed of consequences of plea agreement. | Singer | 5/23/2014 | 2014-Ohio-2218
Ludwig v. Ludwig | L-13-1116 | The trial court did not abuse its discretion when it denied appellant’s motion to modify child support and awarded appellee partial attorney fees. | Pietrykowski | 5/23/2014 | 2014-Ohio-2217
Good v. Murd | L-13-1235 | Landlord not liable for injuries caused to a third party bitten by a tenant’s dog while on the tenant’s leased property. | Singer | 5/23/2014 | 2014-Ohio-2216
State v. Fox | H-13-022 | Trial court did not err in 1989 when it sentenced appellant to two concurrent terms of life in prison after the jury found appellant guilty of two counts of rape of a person under the age of thirteen, through the use of force or threat of force, in violation of R.C. 2907.02(A)(1)(b). | Jensen | 5/23/2014 | 2014-Ohio-2215
Briggs v. GLA Water Mgt. | WD-12-062, WD-12-063 | R.C. 2505.02; final, appealable order; dismissal of contempt motion; prejudice | Osowik | 5/23/2014 | 2014-Ohio-2214
Whitetail Orchard, L.L.C. v. Anadell | E-13-064 | Under R.C. 5302.20(C)(2), conveyance of a portion of real property by all survivorship tenants does not terminate the survivorship tenancy as to the remaining real property. | Yarbrough | 5/16/2014 | 2014-Ohio-2110
State v. Moore | L-13-1166 | Imposition of consecutive sentences is clearly and convincingly contrary to law where the trial court fails to make any of the statutorily required findings under R.C. 2929.14(C)(4). | Yarbrough | 5/16/2014 | 2014-Ohio-2109
Sisson v. Sisson | H-13-014 | A party objecting to a magistrate’s finding of fact, whether or not it is specifically designated as a finding of fact, shall support that objection with a transcript of all the evidence submitted to the magistrate relevant to that finding or an affidavit of that evidence if a transcript is not available. | Singer | 5/16/2014 | 2014-Ohio-2108
State v. Sierra | WD-13-062 | Trial court did not err by denying appellant’s motion to correct sentence as it was barred on the basis of res judicata where appellant could have raised his claims on direct appeal. | Osowik | 5/16/2014 | 2014-Ohio-2107
Safe Auto Ins. Co. v. Barnier | L-13-1277 | Motion to vacate judgment under Civ.R. 60(B) was properly denied. | Singer | 5/16/2014 | 2014-Ohio-2106
In re T.D. | L-13-1237, L-13-1238, L-123-1239 | A juvenile defendant is not deprived of his right to be present during a delinquency proceeding where he waived his right on the record and acted in a manner that was so disruptive that the court could not conduct the proceeding in his presence. | Yarbrough | 5/16/2014 | 2014-Ohio-2105
J.B. v. L.L. | L-13-1269 | Trial court did not err in determining Oakland County, Michigan to be a more convenient forum than Lucas County, Ohio in underlying child custody case. Judgment affirmed. | Osowik | 5/16/2014 | 2014-Ohio-2104
State v. Hull | S-13-029 | Maximum 12 month sentence for a fifth degree felony was not contrary to law. | Singer | 5/16/2014 | 2014-Ohio-2103
State v. Mathis | E-13-017 | The trial court did not err in imposing prison term instead of community control where defendant violated terms of bond, leading the court to revoke bond. The court properly made R.C. 2929.14(C)(4) findings in ordering consecutive sentences. The evidence was not insufficient and verdict was not against the manifest weight of the evidence where testimony and other evidence indicated that the defendant constructively possessed the drugs that were seized. | Jensen | 5/9/2014 | 2014-Ohio-1997
State v. Hines | E-13-054 | The trial court failed to substantially comply with Crim.R. 11(C) where it accepted appellant’s guilty plea without informing him that, as a Tier III sex offender, he would be subject to community notification requirements. | Yarbrough | 5/9/2014 | 2014-Ohio-1996
State v. Evearitt | L-14-1010 | Postconviction motion is barred by res judicata where the arguments supporting the motion could have been raised in a direct appeal. | Yarbrough | 5/9/2014 | 2014-Ohio-1995
State v. Posey | OT-12-028 | The lower court did not abuse its discretion in denying defendant’s presentence motion to withdraw his no contest plea. | Pietrykowski | 5/9/2014 | 2014-Ohio-1994
State v. Parsil | L-13-1044 | Trial court did not err in calling a seven-year-old gross sexual imposition victim as a court’s witness. The court did err in failing to impose a mandatory sentence after finding that corroborative evidence of the accuser’s testimony was introduced at trial. | Singer | 5/9/2014 | 2014-Ohio-1993
Village of Ottawa Hills v. Boice | L-12-1301 | Trial court denied appellant her due process right to present a defense and be heard on factors that the court was required to consider in its treatment of appellee’s claims. Grass-trimming ordinance under which appellant was charged not unconstitutionally vague as applied to this appellant. | Pietrykowski | 5/9/2014 | 2014-Ohio-1992
Mays v. Toledo Hosp. | L-13-1233 | The trial court did not abuse its discretion when it denied an administrator’s motion for relief from judgment of the dismissal of her pro se complaint. Wrongful death; affidavit of merit. | Pietrykowski | 5/9/2014 | 2014-Ohio-1991
Kuyoth v. Village of Kelleys Island | E-13-039 | Trial court acted contrary to due process when it issued a decision on the merits of a petition to establish a street when the petition was not published by publication pursuant to the mandates of R.C. 723.10. | Jensen | 5/9/2014 | 2014-Ohio-1990
State v. Gaines | F-13-004 | Trial court did not err by denying a request for continuance. Appellant’s conviction for receiving stolen property was supported by sufficient evidence and was not against the manifest weight of the evidence. Prosecutor’s remarks did not unduly prejudice appellant or prevent a fair trial. Appellant was not prejudiced by clerical error in the jury instructions. | Osowik | 5/9/2014 | 2014-Ohio-1989
State v. Cornett | WD-13-024 | The trial court erred in sentencing appellant to a fifth degree felony for attempted failure to appear where the underlying offense was a first degree misdemeanor. H.B. 86; State v. Taylor; R.C. 2937.99; R.C. 2923.02(E)(1). | Pietrykowski | 5/9/2014 | 2014-Ohio-1988
Churchill v. Hoffman | WD-13-082 | Tax administrator was statutorily immune from liability in civil suit filed by former taxpayer who was criminally charged with violating village tax ordinance despite not having resided in the village during the tax years in question. The village’s attempt to verify taxpayer’s continued residency in the jurisdiction, which consisted of reviewing water bill that was in the name of taxpayer’s ex-husband, was negligent, but was not malicious, bad faith, or wanton or reckless | Jensen | 5/9/2014 | 2014-Ohio-1987
Lake Erie Towing v. Beatley | E-13-014 | In a contract case, judgment in favor of a company not named as a party plaintiff was in error. | Pietrykowski | 5/9/2014 | 2014-Ohio-1986
State v. Varsel | F-13-006 | R.C. 4511.84, which prohibits wearing earplugs while operating a motor vehicle, is not unconstitutional. | Jensen | 5/2/2014 | 2014-Ohio-1899
State v. Murray | L-10-1059 | Appellate counsel did not render ineffective assistance by failing to seek to supplement the appellate record with the sentencing hearing transcripts from prior criminal actions. | Singer | 5/2/2014 | 2014-Ohio-1898
State v. McNeely | L-13-1027 | In the performance of our duty, under Anders, supra, to conduct an independent review of the record, we have found no potential assignment of error having arguable merit. We grant the motion of counsel to withdraw. | Jensen | 5/2/2014 | 2014-Ohio-1897
McCormick v. Maiden | E-12-072 | Because the disqualification of counsel generally involves the determination of factual issues, we find that the provisions of Civ.R. 52 are applicable to decisions granting or denying a motion to disqualify trial counsel. However, it is not necessary to hold an evidentiary hearing when the motion, coupled with the documents previously filed in the case, contain sufficient facts for the trial court to apply the proper test prior to trial counsel’s disqualification. | Jensen | 5/2/2014 | 2014-Ohio-1896
In re Mi.D. | L-13-1247 | The trial court’s judgment awarding permanent custody of appellant’s children to LCCS is not against the manifest weight of the evidence and is supported by clear and convincing evidence in the record. | Pietrykowski | 5/2/2014 | 2014-Ohio-1895
R & S Roofing Co. v. Mercer-North Am., Inc. | L-13-1161 | Complaint devoid of allegations sufficient to state a claim against a corporate shareholder and corporate attorney supported trial court conclusion that these were frivolous claims. The court acted within its discretion in the imposition of sanctions against plaintiff and its attorney. | Singer | 4/25/2014 | 2014-Ohio-1763
Matrix Acquisitions, L.L.C. v. Georgeff | L-13-1208 | Motion to vacate was inappropriately granted under Civ.R. 60(B), reversed. | Singer | 4/25/2014 | 2014-Ohio-1762
In re A.T. | OT-12-023, OT-12-030 | Juvenile Delinquency Proceedings – Competency to Stand Trial – Court Ordered Sex Specific Diagnostic Assessment and Sex Offender Treatment Before Adjudication of Delinquency – Due Process – Privilege Against Self-Incrimination – Plain Error – Juvenile Admission – Juv.R. 29(D) – Variance between Sentence Pronounced at Disposition Hearing and Subsequent Dispositional Judgments – Vacation of Stay and Imposition of Suspended Sentence on Failure to Meet Conditions | Pietrykowski | 4/25/2014 | 2014-Ohio-1761
First Natl. Bank of Bellevue v. NE Port Invests., L.L.C. | OT-13-024 | The trial court did not err in denying appellants’ motion to intervene. Judgment affirmed. | Osowik | 4/25/2014 | 2014-Ohio-1760

Page: [ 1] 2 3 next